@@ -9,9 +9,9 @@ mod arguments;
 mod column;
 mod connection;
 mod database;
-mod done;
 mod error;
 mod options;
+mod query_result;
 mod row;
 mod statement;
 mod transaction;
@@ -26,9 +26,9 @@ pub use arguments::{SqliteArgumentValue, SqliteArguments};
 pub use column::SqliteColumn;
 pub use connection::SqliteConnection;
 pub use database::Sqlite;
-pub use done::SqliteDone;
 pub use error::SqliteError;
 pub use options::{SqliteConnectOptions, SqliteJournalMode, SqliteSynchronous};
+pub use query_result::SqliteQueryResult;
 pub use row::SqliteRow;
 pub use statement::SqliteStatement;
 pub use transaction::SqliteTransactionManager;
@@ -45,7 +45,6 @@ pub type SqlitePoolOptions = crate::pool::PoolOptions<Sqlite>;
 impl_into_arguments_for_arguments!(SqliteArguments<'q>);
 impl_executor_for_pool_connection!(Sqlite, SqliteConnection, SqliteRow);
 impl_executor_for_transaction!(Sqlite, SqliteRow);
-impl_map_row!(Sqlite, SqliteRow);
 impl_column_index_for_row!(SqliteRow);
 impl_column_index_for_statement!(SqliteStatement);
 impl_acquire!(Sqlite, SqliteConnection);
