@@ -1,12 +1,16 @@
 use std::path::Path;
 
+mod auto_vacuum;
 mod connect;
 mod journal_mode;
+mod locking_mode;
 mod parse;
 mod synchronous;
 
 use crate::connection::LogSettings;
+pub use auto_vacuum::SqliteAutoVacuum;
 pub use journal_mode::SqliteJournalMode;
+pub use locking_mode::SqliteLockingMode;
 use std::{borrow::Cow, time::Duration};
 pub use synchronous::SqliteSynchronous;
 
@@ -50,12 +54,14 @@ pub struct SqliteConnectOptions {
     pub(crate) read_only: bool,
     pub(crate) create_if_missing: bool,
     pub(crate) journal_mode: SqliteJournalMode,
+    pub(crate) locking_mode: SqliteLockingMode,
     pub(crate) foreign_keys: bool,
     pub(crate) shared_cache: bool,
     pub(crate) statement_cache_capacity: usize,
     pub(crate) busy_timeout: Duration,
     pub(crate) log_settings: LogSettings,
     pub(crate) synchronous: SqliteSynchronous,
+    pub(crate) auto_vacuum: SqliteAutoVacuum,
 }
 
 impl Default for SqliteConnectOptions {
@@ -75,9 +81,11 @@ impl SqliteConnectOptions {
             shared_cache: false,
             statement_cache_capacity: 100,
             journal_mode: SqliteJournalMode::Wal,
+            locking_mode: Default::default(),
             busy_timeout: Duration::from_secs(5),
             log_settings: Default::default(),
             synchronous: SqliteSynchronous::Full,
+            auto_vacuum: Default::default(),
         }
     }
 
@@ -104,6 +112,14 @@ impl SqliteConnectOptions {
         self
     }
 
+    /// Sets the [locking mode](https://www.sqlite.org/pragma.html#pragma_locking_mode) for the database connection.
+    ///
+    /// The default locking mode is NORMAL.
+    pub fn locking_mode(mut self, mode: SqliteLockingMode) -> Self {
+        self.locking_mode = mode;
+        self
+    }
+
     /// Sets the [access mode](https://www.sqlite.org/c3ref/open.html) to open the database
     /// for read-only access.
     pub fn read_only(mut self, read_only: bool) -> Self {
@@ -148,4 +164,12 @@ impl SqliteConnectOptions {
         self.synchronous = synchronous;
         self
     }
+
+    /// Sets the [auto_vacuum](https://www.sqlite.org/pragma.html#pragma_auto_vacuum) setting for the database connection.
+    ///
+    /// The default auto_vacuum setting is NONE.
+    pub fn auto_vacuum(mut self, auto_vacuum: SqliteAutoVacuum) -> Self {
+        self.auto_vacuum = auto_vacuum;
+        self
+    }
 }
